OC.L10N.register(
    "core",
    {
    "Please select a file." : "Hãy chọn một tệp.",
    "File is too big" : "Tệp quá lớn",
    "The selected file is not an image." : "Tệp tin được chọn không phải là ảnh.",
    "The selected file cannot be read." : "Tệp tin được chọn không thể đọc.",
    "The file was uploaded" : "Tập tin đã được tải lên",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Tập tin tải lên đã vượt quá upload_max_filesize giới hạn trong hệ thống",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Tập được tải lên vượt quá MAX_FILE_SIZE đã được giới hạn trong biểu mẫu HTML",
    "The file was only partially uploaded" : "Tệp chỉ được tải lên một phần",
    "No file was uploaded" : "Chưa có tệp nào dược tải lên",
    "Missing a temporary folder" : "Thiếu một thư mục tạm thời",
    "Could not write file to disk" : "Không thể ghi tệp lên ổ đĩa",
    "A PHP extension stopped the file upload" : "Một phần mở rộng của PHP đã dừng tải tệp lên",
    "Invalid file provided" : "File không hợp lệ",
    "No image or file provided" : "Không có hình ảnh hoặc tập tin được cung cấp",
    "Unknown filetype" : "Không biết kiểu tập tin",
    "An error occurred. Please contact your admin." : "Có lỗi xảy ra. Vui lòng báo cho quản trị viên.",
    "Invalid image" : "Hình ảnh không hợp lệ",
    "No temporary profile picture available, try again" : "Ảnh cá nhân tạm thời không có giá trị, hãy thử lại",
    "No crop data provided" : "Không có dữ liệu nguồn được cung cấp",
    "No valid crop data provided" : "Dữ liệu trích xuất không hợp lệ",
    "Crop is not square" : "Trích xuất không chuẩn",
    "State token does not match" : "Mã trạng thái không khớp",
    "Invalid app password" : "Mật khẩu ứng dụng không hợp lệ",
    "Could not complete login" : "Không thể hoàn thành đăng nhập",
    "State token missing" : "Thiếu mã thông báo trạng thái",
    "Your login token is invalid or has expired" : "Mã thông báo đăng nhập của bạn không hợp lệ hoặc quá hạn",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Bản phát hành cộng đồng này của Nextcloud không được hỗ trợ và thông báo đẩy bị hạn chế.",
    "Login" : "Đăng nhập",
    "Password reset is disabled" : "Đã tắt chức năng đặt lại mật khẩu",
    "Could not reset password because the token is expired" : "Không thể đặt lại mật khẩu do mã thông báo đã quá hạn",
    "Could not reset password because the token is invalid" : "Không thể đặt lại mật khẩu do mã thông báo không hợp lệ",
    "Password is too long. Maximum allowed length is 469 characters." : "Mật khẩu quá dài. Tối đa 469 kí tự được cho phép.",
    "%s password reset" : "%s thiết lập lại mật khẩu",
    "Password reset" : "Đặt lại mật khẩu",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Nhấp vào nút sau để đặt lại mật khẩu. Nếu bạn không yêu cầu đặt lại mật khẩu, hãy bỏ qua email này.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Nhấp vào liên kết sau để đặt lại mật khẩu của bạn. Nếu bạn không yêu cầu đặt lại mật khẩu, hãy bỏ qua email này.",
    "Reset your password" : "Đổi mật khẩu",
    "Task not found" : "Không tìm thấy nhiệm vụ",
    "Internal error" : "Lỗi nội bộ",
    "Not found" : "Không tìm thấy",
    "Requested task type does not exist" : "Loại nhiệm vụ đã yêu cầu không tồn tại",
    "Necessary language model provider is not available" : "Không có nhà cung cấp mô hình ngôn ngữ cần thiết",
    "No translation provider available" : "Không có nhà cung cấp bản dịch",
    "Could not detect language" : "Không thể phát hiện ngôn ngữ",
    "Unable to translate" : "Không thể dịch",
    "Nextcloud Server" : "Máy chủ vWorkspace",
    "Some of your link shares have been removed" : "Một số liên kết chia sẻ của bạn đã bị xóa",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Do lỗi bảo mật, chúng tôi đã phải xóa một số liên kết chia sẻ của bạn. Vui lòng xem liên kết để biết thêm thông tin.",
    "Learn more ↗" : "Để biết thêm↗",
    "Preparing update" : "Đang chuẩn bị cập nhật",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Bước sửa chữa:",
    "Repair info:" : "Thông tin sửa chữa:",
    "Repair warning:" : "Cảnh báo sửa chữa:",
    "Repair error:" : "Lỗi sửa chữa:",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Vui lòng sử dụng trình cập nhật dòng lệnh vì cập nhật qua trình duyệt bị tắt trong config.php của bạn.",
    "Turned on maintenance mode" : "Bật chế độ bảo trì",
    "Turned off maintenance mode" : "Tắt chế độ bảo trì",
    "Maintenance mode is kept active" : "Chế độ bảo trì đang được kích hoạt",
    "Updating database schema" : "Đang cập nhật lược đồ cơ sở dữ liệu",
    "Updated database" : "Cơ sở dữ liệu đã được cập nhật",
    "Update app \"%s\" from App Store" : "Cập nhật ứng dụng \"%s\" từ Cửa hàng ứng dụng",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Đang kiểm tra liệu lược đồ cơ sở dữ liệu đối với %s có thể được cập nhật hay không (việc này có thể mất nhiều thời gian phụ thuộc vào kích cỡ của cơ sở dữ liệu)",
    "Updated \"%1$s\" to %2$s" : "Đã cập nhật \"%1$s\" lên %2$s",
    "Set log level to debug" : "Thiết lập cấp độ ghi nhật ký để gỡ rối",
    "Reset log level" : "Thiế lập lại cấp độ ghi nhật ký hệ thống",
    "Starting code integrity check" : "Bắt đầu mã kiểm tra sự toàn vẹn",
    "Finished code integrity check" : "Kết thúc mã kiểm tra sự toàn vẹn",
    "%s (incompatible)" : "%s (không tương thích)",
    "The following apps have been disabled: %s" : "Những ứng dụng sau đây đã bị tắt: %s",
    "Already up to date" : "Đã được cập nhật bản mới nhất",
    "Error occurred while checking server setup" : "Có lỗi xảy ra khi kiểm tra thiết lập máy chủ",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Để biết thêm chi tiết, hãy xem tài liệu ↗ {linkstart} {linkend}.",
    "unknown text" : "văn bản không rõ",
    "Hello world!" : "Hello world!",
    "sunny" : "nắng",
    "Hello {name}, the weather is {weather}" : "Xin chào {name}, thời tiết hiện nay {weather}",
    "Hello {name}" : "Xin chào {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Đây là kết quả tìm kiếm của bạn<script>cảnh báo (1)</script></strong>",
    "new" : "mới",
    "_download %n file_::_download %n files_" : ["tải về%ntệp"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Quá trình cập nhật đang được tiến hành, đóng trang này có thể làm gián đoạn quá trình.",
    "Update to {version}" : "Cập nhật lên {version}",
    "An error occurred." : "Đã xảy ra lỗi.",
    "Please reload the page." : "Vui lòng tải lại trang.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Quá trình cập nhật không thành công. Để biết thêm thông tin chi tiết <a href=\"{url}\">đề nghị xem các bài viết trong diễn đàn </a> để xử lý vấn đề này.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Quá trình cập nhật không thành công. Xin vui lòng báo lại vấn đề gặp phải trong tới  <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Cộng đồng Nextcloud</a>.",
    "Continue to {productName}" : "Tiếp tục đến {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Cập nhật đã thành công. Chuyển hướng bạn đến {productName} trong %n seconds."],
    "Apps" : "Ứng dụng",
    "More apps" : "Thêm ứng dụng",
    "_{count} notification_::_{count} notifications_" : ["{count} thông báo"],
    "No" : "Không",
    "Yes" : "Có",
    "Create share" : "Tạo chia sẻ",
    "Failed to add the public link to your Nextcloud" : "Không thể thêm liên kết công khai",
    "Today" : "Hôm nay",
    "Load more results" : "Tải thêm kết quả",
    "Searching …" : "Đang tìm kiếm ...",
    "Start typing to search" : "Nhập để tìm kiếm",
    "Log in" : "Đăng nhập",
    "Logging in …" : "Đang đăng nhập",
    "Server side authentication failed!" : "Xác thực phía máy chủ không thành công!",
    "Please contact your administrator." : "Vui lòng liên hệ với quản trị viên.",
    "An internal error occurred." : "Đã xảy ra một lỗi nội bộ.",
    "Please try again or contact your administrator." : "Vui lòng thử lại hoặc liên hệ quản trị của bạn.",
    "Password" : "Mật khẩu",
    "Log in to {productName}" : "Đăng nhập vào {productName}",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Chúng tôi đã phát hiện nhiều lần đăng nhập không hợp lệ từ IP của bạn. Do đó, lần đăng nhập tiếp theo của bạn được điều chỉnh lên đến 30 giây.",
    "Account name or email" : "Tên tài khoản hoặc email",
    "Log in with a device" : "Đăng nhập bằng thiết bị",
    "Your account is not setup for passwordless login." : "Tài khoản của bạn chưa được thiết lập để đăng nhập không cần mật khẩu.",
    "Browser not supported" : "Trình duyệt không được hỗ trợ",
    "Passwordless authentication is not supported in your browser." : "Xác thực không cần mật khẩu không được hỗ trợ trong trình duyệt của bạn.",
    "Your connection is not secure" : "Kết nối của bạn không an toàn",
    "Passwordless authentication is only available over a secure connection." : "Xác thực không cần mật khẩu chỉ khả dụng qua kết nối an toàn.",
    "Reset password" : "Khôi phục mật khẩu",
    "Couldn't send reset email. Please contact your administrator." : "Không thể gửi thư điện tử yêu cầu thiết lập lại. Xin vui lòng liên hệ quản trị hệ thống",
    "Password cannot be changed. Please contact your administrator." : "Không thể thay đổi mật khẩu. Vui lòng liên hệ với quản trị viên của bạn.",
    "Back to login" : "Quay lại trang đăng nhập",
    "New password" : "Mật khẩu mới",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Các tệp của bạn được mã hóa. Sẽ không có cách nào để lấy lại dữ liệu của bạn sau khi mật khẩu của bạn được đặt lại. Nếu bạn không chắc chắn phải làm gì, vui lòng liên hệ với quản trị viên của bạn trước khi tiếp tục. Bạn có thực sự muốn tiếp tục?",
    "I know what I'm doing" : "Tôi biết tôi đang làm gì",
    "Resetting password" : "Đặt lại mật khẩu",
    "Recommended apps" : "Ứng dụng được đề xuất",
    "Loading apps …" : "Đang tải ứng dụng ...",
    "Could not fetch list of apps from the App Store." : "Không thể tìm nạp danh sách ứng dụng từ App Store.",
    "App download or installation failed" : "Tải xuống hoặc cài đặt ứng dụng không thành công",
    "Cannot install this app because it is not compatible" : "Không thể cài đặt ứng dụng này vì nó không tương thích",
    "Cannot install this app" : "Không thể cài đặt ứng dụng này",
    "Skip" : "Bỏ qua",
    "Installing apps …" : "Đang cài đặt ứng dụng ...",
    "Install recommended apps" : "Cài đặt các ứng dụng được đề xuất",
    "Schedule work & meetings, synced with all your devices." : "Lên lịch làm việc và cuộc họp, đồng bộ hóa với tất cả các thiết bị của bạn.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Giữ đồng nghiệp và bạn bè của bạn ở một nơi mà không làm rò rỉ thông tin cá nhân của họ.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Ứng dụng email đơn giản được tích hợp độc đáo với Tệp, Danh bạ và Lịch.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Trò chuyện, cuộc gọi video, chia sẻ màn hình, cuộc họp trực tuyến và hội nghị trên web - trong trình duyệt của bạn và với các ứng dụng dành cho thiết bị di động.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Tài liệu, bảng tính và bản trình bày cộng tác, được xây dựng trên Collabora Online.",
    "Distraction free note taking app." : "Ứng dụng ghi chú không gây xao lãng.",
    "Settings menu" : "Trình đơn thiết lập",
    "Search contacts" : "Tìm kiếm liên hệ",
    "Reset search" : "Đặt lại tìm kiếm",
    "Search contacts …" : "Tìm liên hệ ...",
    "Could not load your contacts" : "Không thể tải liên hệ của bạn",
    "No contacts found" : "Không tìm thấy liên hệ nào",
    "Show all contacts" : "Hiện tất cả liên hệ",
    "Install the Contacts app" : "Cài đặt ứng dụng Danh bạ",
    "Loading your contacts …" : "Đang tải liên hệ của bạn ...",
    "Looking for {term} …" : "Đang tìm kiếm {term} ...",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Tìm kiếm bắt đầu khi bạn bắt đầu nhập và có thể đạt được kết quả bằng các phím mũi tên",
    "Search for {name} only" : "Chỉ tìm kiếm {name}",
    "Loading more results …" : "Tải thêm kết quả ...",
    "Search" : "Tìm kiếm",
    "No results for {query}" : "Không có kết quả cho {query}",
    "Press Enter to start searching" : "Nhấn Enter để bắt đầu tìm kiếm",
    "An error occurred while searching for {type}" : "Đã xảy ra lỗi khi tìm kiếm {type}",
    "Forgot password?" : "Quên mật khẩu sao?",
    "Back to login form" : "Quay lại trang đăng nhập",
    "Back" : "Quay lại",
    "Login form is disabled." : "Trang đăng nhập bị vô hiệu.",
    "Edit Profile" : "Chỉnh sửa hồ sơ",
    "The headline and about sections will show up here" : "Dòng tiêu đề và phần giới thiệu sẽ hiển thị ở đây",
    "You have not added any info yet" : "Bạn chưa thêm bất kỳ thông tin nào",
    "{user} has not added any info yet" : "{user} chưa thêm bất kỳ thông tin nào",
    "Error opening the user status modal, try hard refreshing the page" : "Lỗi khi mở phương thức trạng thái người dùng, hãy thử làm mới trang",
    "More actions" : "Nhiều hành động hơn",
    "This browser is not supported" : "Trình duyệt này không được hỗ trợ",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Trình duyệt của bạn không được hỗ trợ. Vui lòng nâng cấp lên phiên bản mới hơn hoặc phiên bản được hỗ trợ.",
    "Continue with this unsupported browser" : "Tiếp tục với trình duyệt không được hỗ trợ này",
    "Supported versions" : "Các phiên bản được hỗ trợ",
    "{name} version {version} and above" : "{name} phiên bản {version} trở lên",
    "Search {types} …" : "Tìm kiếm {types} ...",
    "Choose {file}" : "Chọn {tập tin}",
    "Choose" : "Chọn",
    "Copy to {target}" : "Sao chép vào {mục tiêu}",
    "Copy" : "Sao chép",
    "Move to {target}" : "Di chuyển đến {mục tiêu}",
    "Move" : "Chuyển",
    "OK" : "Đồng ý",
    "read-only" : "Chỉ đọc",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} tập tin xung đột"],
    "One file conflict" : "Một tập tin xung đột",
    "New Files" : "File mới",
    "Already existing files" : "Các file đang tồn tại",
    "Which files do you want to keep?" : "Bạn muốn tiếp tục với những tập tin nào?",
    "If you select both versions, the copied file will have a number added to its name." : "Nếu bạn chọn cả hai phiên bản, tập tin được sao chép sẽ được đánh thêm số vào tên của nó.",
    "Cancel" : "Hủy",
    "Continue" : "Tiếp tục",
    "(all selected)" : "(Tất cả các lựa chọn)",
    "({count} selected)" : "({count} được chọn)",
    "Error loading file exists template" : "Lỗi khi tải tập tin mẫu đã tồn tại",
    "Saving …" : "Đang lưu ...",
    "seconds ago" : "vài giây trước",
    "Connection to server lost" : "Kết nối tới máy chủ bị mất",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Xảy ra lỗi khi tải trang, tải lại trong %n giây"],
    "Add to a project" : "Thêm vào dự án",
    "Show details" : "Hiển thị chi tiết",
    "Hide details" : "Ẩn chi tiết",
    "Rename project" : "Đổi tên dự án",
    "Failed to rename the project" : "Không thể đổi tên dự án",
    "Failed to create a project" : "Không thể tạo dự án",
    "Failed to add the item to the project" : "Không thể thêm mục vào dự án",
    "Connect items to a project to make them easier to find" : "Kết nối các mục với dự án để dễ tìm thấy chúng hơn",
    "Type to search for existing projects" : "Nhập để tìm kiếm các dự án hiện có",
    "New in" : "Mới trong",
    "View changelog" : "Xem nhật ký thay đổi",
    "Very weak password" : "Mật khẩu rất yếu",
    "Weak password" : "Mật khẩu yếu",
    "So-so password" : "Mật khẩu tạm được",
    "Good password" : "Mật khẩu tốt",
    "Strong password" : "Mật khẩu mạnh",
    "No action available" : "Không có hành động nào",
    "Error fetching contact actions" : "Lỗi khi nạp liên hệ",
    "Close \"{dialogTitle}\" dialog" : "Đóng hộp thoại \"{dialogTitle}\"",
    "Non-existing tag #{tag}" : "Thẻ không tồn tại # {tag}",
    "Restricted" : "Bị giới hạn",
    "Invisible" : "Vô hình",
    "Delete" : "Xóa",
    "Rename" : "Sửa tên",
    "Collaborative tags" : "Thẻ cộng tác",
    "No tags found" : "Không tìm thấy thẻ",
    "Personal" : "Cá nhân",
    "Admin" : "Quản trị",
    "Help" : "Giúp đỡ",
    "Access forbidden" : "Truy cập bị cấm",
    "Profile not found" : "Không tìm thấy hồ sơ",
    "The profile does not exist." : "Hồ sơ không tồn tại.",
    "Back to %s" : "Quay lại %s",
    "Page not found" : "Trang không tìm thấy",
    "The page could not be found on the server or you may not be allowed to view it." : "Không thể tìm thấy trang trên máy chủ hoặc bạn có thể không được phép xem nó.",
    "Too many requests" : "Có quá nhiều yêu cầu",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Có quá nhiều yêu cầu từ mạng của bạn. Thử lại sau hoặc liên hệ với quản trị viên của bạn nếu đây là lỗi.",
    "Error" : "Lỗi",
    "Previous" : "Trước",
    "Internal Server Error" : "Lỗi máy chủ.",
    "The server was unable to complete your request." : "Máy chủ không thể hoàn thành được yêu cầu của bạn",
    "If this happens again, please send the technical details below to the server administrator." : "Nếu điều này tiếp tục xảy ra, xin vui lòng gửi thông tin kỹ thuật chi tiết tới người quản trị hệ thống.",
    "More details can be found in the server log." : "Các chi tiết có thể được tìm thấy trong nhật ký máy chủ.",
    "Technical details" : "Chi tiết kỹ thuật",
    "Remote Address: %s" : "Địa chỉ bên ngoài: %s",
    "Request ID: %s" : "Yêu cầu ID:%s",
    "Type: %s" : "Loại: %s",
    "Code: %s" : "Mã: %s",
    "Message: %s" : "Thông điệp:%s",
    "File: %s" : "Tệp: %s",
    "Line: %s" : "Dòng: %s",
    "Trace" : "Theo dõi",
    "Security warning" : "Cảnh báo bảo mật",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Thư mục và file dữ liệu của bạn có thể được truy cập từ internet bởi vì file .htaccess không hoạt động",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Để biết thông tin về cách cấu hình đúng máy chủ của bạn, vui lòng xem <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">tài liệu</a>.",
    "Create an <strong>admin account</strong>" : "Tạo một <strong>tài khoản quản trị</strong>",
    "Show password" : "Hiện mật khẩu",
    "Toggle password visibility" : "Chuyển chế độ hiển thị mật khẩu",
    "Storage & database" : "Lưu trữ & cơ sở dữ liệu",
    "Data folder" : "Thư mục dữ liệu",
    "Configure the database" : "Cấu hình cơ sở dữ liệu",
    "Only %s is available." : "Chỉ %s khả dụng.",
    "Install and activate additional PHP modules to choose other database types." : "Cài đặt và kích hoạt các mô-đun PHP bổ sung để chọn các loại cơ sở dữ liệu khác.",
    "For more details check out the documentation." : "Để biết thêm chi tiết, hãy kiểm tra tài liệu.",
    "Database password" : "Mật khẩu cơ sở dữ liệu",
    "Database name" : "Tên cơ sở dữ liệu",
    "Database tablespace" : "Cơ sở dữ liệu tablespace",
    "Database host" : "Database host",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Vui lòng xác định số cổng cùng với tên máy chủ lưu trữ (ví dụ: localhost: 5432).",
    "Performance warning" : "Cảnh báo hiệu suất",
    "You chose SQLite as database." : "Bạn đã chọn SQLite làm cơ sở dữ liệu.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite chỉ nên được sử dụng cho các trường hợp tối thiểu và phát triển. Đối với sản xuất, chúng tôi khuyên bạn nên sử dụng một phụ trợ cơ sở dữ liệu khác.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Nếu bạn sử dụng máy khách để đồng bộ hóa tệp, việc sử dụng SQLite rất không được khuyến khích.",
    "Install" : "Cài đặt",
    "Installing …" : "Đang cài đặt",
    "Need help?" : "Cần hỗ trợ ?",
    "See the documentation" : "Xem tài liệu",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Có vẻ như bạn đang cố gắng cài đặt lại Nextcloud của mình. Tuy nhiên, CAN_INSTALL tệp bị thiếu trong thư mục cấu hình của bạn. Vui lòng tạo tệp CAN_INSTALL trong thư mục cấu hình của bạn để tiếp tục.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Không thể loại bỏ CAN_INSTALL khỏi thư mục cấu hình. Vui lòng xóa tệp này theo cách thủ công.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ứng dụng này yêu cầu JavaScript để hoạt động chính xác. Vui lòng {linkstart} bật JavaScript {linkend} và tải lại trang.",
    "Skip to main content" : "Chuyển sang nội dung chính",
    "Skip to navigation of app" : "Chuyển tới điều hướng của ứng dụng",
    "Go to %s" : "Đi tới %s",
    "Get your own free account" : "Nhận tài khoản miễn phí",
    "Connect to your account" : "Kết nối tài khoản của bạn",
    "Please log in before granting %1$s access to your %2$s account." : "Vui lòng đăng nhập trước khi cấp quyền cho %1$s truy cập vào tài khoản %2$s của bạn.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Nếu bạn không cố gắng thiết lập một thiết bị hoặc ứng dụng mới, ai đó đang cố lừa bạn cấp cho họ quyền truy cập vào dữ liệu của bạn. Trong trường hợp này, không tiếp tục và thay vào đó hãy liên hệ với quản trị viên hệ thống của bạn.",
    "Grant access" : "Cấp quyền truy cập",
    "Account access" : "Truy cập tài khoản",
    "Currently logged in as %1$s (%2$s)." : "Hiện đang đăng nhập với tư cách %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Bạn sắp cấp quyền truy cập cho %1$s vào tài khoản %2$s của mình.",
    "Account connected" : "Tài khoản đã được kết nối",
    "Your client should now be connected!" : "Máy khách của bạn bây giờ sẽ được kết nối!",
    "You can close this window." : "Bạn có thể đóng lại cửa sổ này",
    "This share is password-protected" : "Chia sẽ này được bảo vệ bởi mật khẩu",
    "The password is wrong or expired. Please try again or request a new one." : "Mật khẩu không đúng hoặc đã hết hạn.\nVui lòng thử lại hoặc yêu cầu mật khẩu mới.",
    "Please type in your email address to request a temporary password" : "Vui lòng nhập địa chỉ email để yêu cầu mật khẩu tạm",
    "Email address" : "Địa chỉ thư điện tử",
    "Password sent!" : "Đã gửi Mật khẩu",
    "You are not authorized to request a password for this share" : "Bạn không được phép yêu cầu mật khẩu cho chia sẻ này",
    "Two-factor authentication" : "Xác thực 2 bước",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Bảo mật nâng cao được bật cho tài khoản của bạn. Chọn yếu tố thứ hai để xác thực:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Không thể tải ít nhất một trong các phương pháp xác thực hai yếu tố được kích hoạt của bạn. Vui lòng liên hệ với quản trị viên của bạn.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Xác thực hai yếu tố được thực thi nhưng chưa được định cấu hình trên tài khoản của bạn. Liên hệ với quản trị viên của bạn để được trợ giúp.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Xác thực hai yếu tố được thực thi nhưng chưa được định cấu hình trên tài khoản của bạn. Vui lòng tiếp tục thiết lập xác thực hai yếu tố.",
    "Set up two-factor authentication" : "Cài đặt bảo mật hai lớp",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Xác thực hai yếu tố được thực thi nhưng chưa được định cấu hình trên tài khoản của bạn. Sử dụng một trong các mã dự phòng của bạn để đăng nhập hoặc liên hệ với quản trị viên của bạn để được trợ giúp.",
    "Use backup code" : "Sử dụng mã dự phòng",
    "Cancel login" : "Hủy đăng nhập",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Bảo mật nâng cao được thực thi cho tài khoản của bạn. Chọn nhà cung cấp để thiết lập:",
    "Error while validating your second factor" : "Lỗi khi xác thực 2 bước",
    "Access through untrusted domain" : "Truy nhập thông qua tên miền không đáng tin",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Xin vui lòng liên hệ với quản trị hệ thống của bạn. Nếu ban là người quản trị hệ thống, sửa phần thiết lập \"trusted_domains\" trong file config/config.php giống như trong ví dụ tại file config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Thông tin thêm về cách cấu hình có thể được tìm thấy trong tài liệu %1$s %2$s.",
    "App update required" : "Ứng dụng yêu cầu cập nhật",
    "%1$s will be updated to version %2$s" : "%1$s sẽ được cập nhật lên phiên bản %2$s",
    "The following apps will be updated:" : "Các ứng dụng sau sẽ được cập nhật:",
    "These incompatible apps will be disabled:" : "Những ứng dụng không tương thích sẽ bị tắt:",
    "The theme %s has been disabled." : "Giao diện %s đã bị tắt.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Bạn cần phải bảo đảm rằng cơ sở dữ liệu, thư mục chứa file cấu hình hệ thống và thư mục chứa dữ liệu người dùng phải được sao lưu trước khi thực hiện.",
    "Start update" : "Bắt đầu cập nhật",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Để tránh thời gian quá hạn với các cài đặt lớn hơn, bạn có thể thực hiện chạy lệnh sau từ thư mục cài đặt:",
    "Detailed logs" : "Nhật ký chi tiết",
    "Update needed" : "Cần phải cập nhật",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Trợ giúp, xem <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Tôi biết rằng nếu tôi tiếp tục thực hiện cập nhập qua giao diện Web có rủi ro, mà yêu cầu đó chạy trong một khoảng thời gian bị quá hạn và có thể gây mất dữ liệu, nếu tôi có một bản sao và tôi biết cách khôi phục bản cài đặt đã sao lưu trong trường hợp bị lỗi khi cập nhật.",
    "Upgrade via web on my own risk" : "Nâng cấp qua web",
    "Maintenance mode" : "Chế độ bảo trì",
    "This %s instance is currently in maintenance mode, which may take a while." : "Bản cài đặt%s hiện tại đang trong chế độ \"bảo trì\", do vậy có thể bạn cần phải đợi thêm chút ít thời gian.",
    "This page will refresh itself when the instance is available again." : "Trang này sẽ tự làm mới khi phiên bản khả dụng trở lại.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Liên hệ với người quản trị nếu lỗi này vẫn tồn tại hoặc xuất hiện bất ngờ.",
    "The user limit of this instance is reached." : "Đã đạt đến giới hạn người dùng của phiên bản này.",
    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Nhập mã đăng ký của bạn vào ứng dụng hỗ trợ để tăng giới hạn người dùng. Điều này cũng cấp cho bạn tất cả các lợi ích bổ sung mà Nextcloud Enterprise cung cấp và rất được khuyến khích cho hoạt động của các công ty.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Máy chủ web của bạn chưa được thiết lập đúng cách để cho phép đồng bộ hóa tệp vì giao diện WebDAV dường như bị hỏng.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Máy chủ web của bạn không được thiết lập đúng cách để xử lý \"{url}\". Bạn có thể tìm thêm thông tin trong tài liệu {linkstart}↗{linkend}.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Máy chủ web của bạn không được thiết lập đúng cách để xử lý \"{url}\". Điều này rất có thể liên quan đến cấu hình máy chủ web chưa được cập nhật để phân phối trực tiếp thư mục này. Vui lòng so sánh cấu hình của bạn với các quy tắc rewrite trong \".htaccess\" cho Apache hoặc quy tắc được cung cấp trong tài liệu dành cho Nginx tại trang tài liệu {linkstart}của nó ↗{linkend}. Trên Nginx, đó thường là những dòng bắt đầu bằng \"location ~\" cần cập nhật.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Máy chủ web của bạn không được thiết lập đúng cách để phân phối các tệp .woff2. Đây thường là sự cố với cấu hình Nginx. Đối với Nextcloud 15, nó cần điều chỉnh để phân phối các tệp .woff2. So sánh cấu hình Nginx của bạn với cấu hình đề xuất trong {linkstart}tài liệu ↗{linkend} của chúng tôi.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Bạn đang truy cập phiên bản của mình qua kết nối bảo mật, tuy nhiên phiên bản của bạn đang tạo ra các URL không an toàn. Điều này rất có thể có nghĩa là bạn đang đứng sau một proxy ngược và các biến cấu hình ghi đè không được đặt chính xác. Vui lòng đọc {linkstart} trang tài liệu về {linkend} này ↗.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Thư mục dữ liệu và tệp của bạn có thể truy cập được từ internet. Tệp .htaccess không hoạt động. Chúng tôi khuyên bạn nên cấu hình máy chủ web của mình để thư mục dữ liệu không thể truy cập được nữa hoặc di chuyển thư mục dữ liệu ra ngoài thư mục gốc tài liệu máy chủ web.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Tiêu đề HTTP \"{header}\" không được đặt thành \"{expected}\". Đây là một rủi ro tiềm ẩn về bảo mật hoặc quyền riêng tư, vì bạn nên điều chỉnh cài đặt này cho phù hợp.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "Tiêu đề HTTP \"{header}\" không được đặt thành \"{expected}\". Một số tính năng có thể không hoạt động chính xác, vì bạn nên điều chỉnh cài đặt này cho phù hợp.",
    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Tiêu đề HTTP \"{header}\" không chứa \"{expected}\". Đây là một rủi ro tiềm ẩn về bảo mật hoặc quyền riêng tư, vì bạn nên điều chỉnh cài đặt này cho phù hợp.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "Tiêu đề HTTP \"{header}\" không được đặt thành \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" hoặc \"{val5}\". Điều này có thể làm rò rỉ thông tin giới thiệu. Xem Khuyến nghị ↗ {linkstart}W3C {linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "Tiêu đề HTTP \"Strict-Transport-Security\" không được đặt thành ít nhất \"{seconds}\" giây. Để tăng cường bảo mật, bạn nên bật HSTS như được mô tả trong mẹo ↗ bảo mật {linkstart} {linkend}.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Truy cập trang web không an toàn thông qua HTTP. Thay vào đó, bạn nên thiết lập máy chủ của mình để yêu cầu HTTPS, như được mô tả trong {linkstart} mẹo ↗ bảo mật {linkend}. Nếu không có nó, một số chức năng web quan trọng như \"sao chép vào khay nhớ tạm\" hoặc \"nhân viên dịch vụ\" sẽ không hoạt động!",
    "Currently open" : "Hiện đang mở",
    "Wrong username or password." : "Tên người dùng hoặc mật khẩu sai.",
    "User disabled" : "Vô hiệu hóa sử dụng",
    "Username or email" : "Tên truy cập hoặc email",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Nếu tài khoản này tồn tại, một thông báo đặt lại mật khẩu đã được gửi đến địa chỉ email của nó. Nếu bạn không nhận được, hãy xác minh địa chỉ email và / hoặc tên tài khoản của bạn, kiểm tra thư mục spam / rác hoặc yêu cầu chính quyền địa phương của bạn trợ giúp.",
    "Error loading message template: {error}" : "Lỗi khi tải mẫu thông điệp: {error}",
    "Users" : "Người dùng",
    "Username" : "Tên đăng nhập",
    "Database user" : "Người dùng cơ sở dữ liệu",
    "This action requires you to confirm your password" : "Để thực hiện hành động này, yêu cầu bạn phải nhập lại mật khẩu",
    "Confirm your password" : "Xác nhận mật khẩu của bạn",
    "Confirm" : "Xác nhận",
    "App token" : "Dấu hiệu ứng dụng",
    "Alternative log in using app token" : "Đăng nhập thay thế bằng mã thông báo ứng dụng",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Xin vui lòng sử dụng lệnh cập nhật bằng dòng lệnh bởi vì bạn có một bản cài đặt lớn có hơn 50 người dùng."
},
"nplurals=1; plural=0;");
